==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/ScaleIOVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ScaleIOVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent<A>{
  public ScaleIOVolumeSourceFluentImpl() {
  }
  public ScaleIOVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.ScaleIOVolumeSource instance) {
    this.withFsType(instance.getFsType()); 
    this.withGateway(instance.getGateway()); 
    this.withProtectionDomain(instance.getProtectionDomain()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withSslEnabled(instance.getSslEnabled()); 
    this.withStorageMode(instance.getStorageMode()); 
    this.withStoragePool(instance.getStoragePool()); 
    this.withSystem(instance.getSystem()); 
    this.withVolumeName(instance.getVolumeName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String fsType;
  private java.lang.String gateway;
  private java.lang.String protectionDomain;
  private java.lang.Boolean readOnly;
  private io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder secretRef;
  private java.lang.Boolean sslEnabled;
  private java.lang.String storageMode;
  private java.lang.String storagePool;
  private java.lang.String system;
  private java.lang.String volumeName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public java.lang.String getGateway() {
    return this.gateway;
  }
  public A withGateway(java.lang.String gateway) {
    this.gateway=gateway; return (A) this;
  }
  public java.lang.Boolean hasGateway() {
    return this.gateway != null;
  }
  
  /**
   * Method is deprecated. use withGateway instead.
   */
  @java.lang.Deprecated
  public A withNewGateway(java.lang.String arg0) {
    return (A)withGateway(new String(arg0));
  }
  public java.lang.String getProtectionDomain() {
    return this.protectionDomain;
  }
  public A withProtectionDomain(java.lang.String protectionDomain) {
    this.protectionDomain=protectionDomain; return (A) this;
  }
  public java.lang.Boolean hasProtectionDomain() {
    return this.protectionDomain != null;
  }
  
  /**
   * Method is deprecated. use withProtectionDomain instead.
   */
  @java.lang.Deprecated
  public A withNewProtectionDomain(java.lang.String arg0) {
    return (A)withProtectionDomain(new String(arg0));
  }
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item) {
    return new io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public java.lang.Boolean getSslEnabled() {
    return this.sslEnabled;
  }
  public A withSslEnabled(java.lang.Boolean sslEnabled) {
    this.sslEnabled=sslEnabled; return (A) this;
  }
  public java.lang.Boolean hasSslEnabled() {
    return this.sslEnabled != null;
  }
  public java.lang.String getStorageMode() {
    return this.storageMode;
  }
  public A withStorageMode(java.lang.String storageMode) {
    this.storageMode=storageMode; return (A) this;
  }
  public java.lang.Boolean hasStorageMode() {
    return this.storageMode != null;
  }
  
  /**
   * Method is deprecated. use withStorageMode instead.
   */
  @java.lang.Deprecated
  public A withNewStorageMode(java.lang.String arg0) {
    return (A)withStorageMode(new String(arg0));
  }
  public java.lang.String getStoragePool() {
    return this.storagePool;
  }
  public A withStoragePool(java.lang.String storagePool) {
    this.storagePool=storagePool; return (A) this;
  }
  public java.lang.Boolean hasStoragePool() {
    return this.storagePool != null;
  }
  
  /**
   * Method is deprecated. use withStoragePool instead.
   */
  @java.lang.Deprecated
  public A withNewStoragePool(java.lang.String arg0) {
    return (A)withStoragePool(new String(arg0));
  }
  public java.lang.String getSystem() {
    return this.system;
  }
  public A withSystem(java.lang.String system) {
    this.system=system; return (A) this;
  }
  public java.lang.Boolean hasSystem() {
    return this.system != null;
  }
  
  /**
   * Method is deprecated. use withSystem instead.
   */
  @java.lang.Deprecated
  public A withNewSystem(java.lang.String arg0) {
    return (A)withSystem(new String(arg0));
  }
  public java.lang.String getVolumeName() {
    return this.volumeName;
  }
  public A withVolumeName(java.lang.String volumeName) {
    this.volumeName=volumeName; return (A) this;
  }
  public java.lang.Boolean hasVolumeName() {
    return this.volumeName != null;
  }
  
  /**
   * Method is deprecated. use withVolumeName instead.
   */
  @java.lang.Deprecated
  public A withNewVolumeName(java.lang.String arg0) {
    return (A)withVolumeName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ScaleIOVolumeSourceFluentImpl that = (ScaleIOVolumeSourceFluentImpl) o;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (gateway != null ? !gateway.equals(that.gateway) :that.gateway != null) return false;
    if (protectionDomain != null ? !protectionDomain.equals(that.protectionDomain) :that.protectionDomain != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (sslEnabled != null ? !sslEnabled.equals(that.sslEnabled) :that.sslEnabled != null) return false;
    if (storageMode != null ? !storageMode.equals(that.storageMode) :that.storageMode != null) return false;
    if (storagePool != null ? !storagePool.equals(that.storagePool) :that.storagePool != null) return false;
    if (system != null ? !system.equals(that.system) :that.system != null) return false;
    if (volumeName != null ? !volumeName.equals(that.volumeName) :that.volumeName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fsType,  gateway,  protectionDomain,  readOnly,  secretRef,  sslEnabled,  storageMode,  storagePool,  system,  volumeName,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.LocalObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<N>> implements io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.LocalObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) ScaleIOVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/ScaleIOVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ScaleIOVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent<A>{
  public ScaleIOVolumeSourceFluentImpl() {
  }
  public ScaleIOVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.ScaleIOVolumeSource instance) {
    this.withFsType(instance.getFsType()); 
    this.withGateway(instance.getGateway()); 
    this.withProtectionDomain(instance.getProtectionDomain()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withSslEnabled(instance.getSslEnabled()); 
    this.withStorageMode(instance.getStorageMode()); 
    this.withStoragePool(instance.getStoragePool()); 
    this.withSystem(instance.getSystem()); 
    this.withVolumeName(instance.getVolumeName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String fsType;
  private java.lang.String gateway;
  private java.lang.String protectionDomain;
  private java.lang.Boolean readOnly;
  private io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder secretRef;
  private java.lang.Boolean sslEnabled;
  private java.lang.String storageMode;
  private java.lang.String storagePool;
  private java.lang.String system;
  private java.lang.String volumeName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public java.lang.String getGateway() {
    return this.gateway;
  }
  public A withGateway(java.lang.String gateway) {
    this.gateway=gateway; return (A) this;
  }
  public java.lang.Boolean hasGateway() {
    return this.gateway != null;
  }
  
  /**
   * Method is deprecated. use withGateway instead.
   */
  @java.lang.Deprecated
  public A withNewGateway(java.lang.String arg0) {
    return (A)withGateway(new String(arg0));
  }
  public java.lang.String getProtectionDomain() {
    return this.protectionDomain;
  }
  public A withProtectionDomain(java.lang.String protectionDomain) {
    this.protectionDomain=protectionDomain; return (A) this;
  }
  public java.lang.Boolean hasProtectionDomain() {
    return this.protectionDomain != null;
  }
  
  /**
   * Method is deprecated. use withProtectionDomain instead.
   */
  @java.lang.Deprecated
  public A withNewProtectionDomain(java.lang.String arg0) {
    return (A)withProtectionDomain(new String(arg0));
  }
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item) {
    return new io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public java.lang.Boolean getSslEnabled() {
    return this.sslEnabled;
  }
  public A withSslEnabled(java.lang.Boolean sslEnabled) {
    this.sslEnabled=sslEnabled; return (A) this;
  }
  public java.lang.Boolean hasSslEnabled() {
    return this.sslEnabled != null;
  }
  public java.lang.String getStorageMode() {
    return this.storageMode;
  }
  public A withStorageMode(java.lang.String storageMode) {
    this.storageMode=storageMode; return (A) this;
  }
  public java.lang.Boolean hasStorageMode() {
    return this.storageMode != null;
  }
  
  /**
   * Method is deprecated. use withStorageMode instead.
   */
  @java.lang.Deprecated
  public A withNewStorageMode(java.lang.String arg0) {
    return (A)withStorageMode(new String(arg0));
  }
  public java.lang.String getStoragePool() {
    return this.storagePool;
  }
  public A withStoragePool(java.lang.String storagePool) {
    this.storagePool=storagePool; return (A) this;
  }
  public java.lang.Boolean hasStoragePool() {
    return this.storagePool != null;
  }
  
  /**
   * Method is deprecated. use withStoragePool instead.
   */
  @java.lang.Deprecated
  public A withNewStoragePool(java.lang.String arg0) {
    return (A)withStoragePool(new String(arg0));
  }
  public java.lang.String getSystem() {
    return this.system;
  }
  public A withSystem(java.lang.String system) {
    this.system=system; return (A) this;
  }
  public java.lang.Boolean hasSystem() {
    return this.system != null;
  }
  
  /**
   * Method is deprecated. use withSystem instead.
   */
  @java.lang.Deprecated
  public A withNewSystem(java.lang.String arg0) {
    return (A)withSystem(new String(arg0));
  }
  public java.lang.String getVolumeName() {
    return this.volumeName;
  }
  public A withVolumeName(java.lang.String volumeName) {
    this.volumeName=volumeName; return (A) this;
  }
  public java.lang.Boolean hasVolumeName() {
    return this.volumeName != null;
  }
  
  /**
   * Method is deprecated. use withVolumeName instead.
   */
  @java.lang.Deprecated
  public A withNewVolumeName(java.lang.String arg0) {
    return (A)withVolumeName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ScaleIOVolumeSourceFluentImpl that = (ScaleIOVolumeSourceFluentImpl) o;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (gateway != null ? !gateway.equals(that.gateway) :that.gateway != null) return false;
    if (protectionDomain != null ? !protectionDomain.equals(that.protectionDomain) :that.protectionDomain != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (sslEnabled != null ? !sslEnabled.equals(that.sslEnabled) :that.sslEnabled != null) return false;
    if (storageMode != null ? !storageMode.equals(that.storageMode) :that.storageMode != null) return false;
    if (storagePool != null ? !storagePool.equals(that.storagePool) :that.storagePool != null) return false;
    if (system != null ? !system.equals(that.system) :that.system != null) return false;
    if (volumeName != null ? !volumeName.equals(that.volumeName) :that.volumeName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fsType,  gateway,  protectionDomain,  readOnly,  secretRef,  sslEnabled,  storageMode,  storagePool,  system,  volumeName,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.LocalObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<N>> implements io.fabric8.kubernetes.api.model.ScaleIOVolumeSourceFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.LocalObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) ScaleIOVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
